const type = {};
const types = [
    'Array',
    'Object',
    'String',
    'Date',
    'RegExp',
    'Function',
    'Boolean',
    'Number',
    'Error',
    'Null',
    'Undefined'
];
/**
 * Check the type of a value.
 */
type.is = (type, val) => Object.prototype.toString.call(val).slice(8, -1) === type;
// Populate helper methods.
types.forEach(t => (type[`is${t}`] = (v) => type.is(t, v)));

/**
 * Return the value or execute as a function
 */
function value(val, ...args) {
    return type.isFunction(val) ? val.apply(this, args) : val;
}

/**
 * Round a number to a given number of decimal places.
 */
function round(val, places = 2) {
    return Number(val.toFixed(places));
}

/**
 * Get the ordinal value for a given number.
 */
function ordinal(num) {
    const suffix = ['th', 'st', 'nd', 'rd'], v = num % 100;
    return num + (suffix[(v - 20) % 10] || suffix[v] || suffix[0]);
}

/**
 * Convert seconds to a human readable time string.
 */
function time(s) {
    const hours = Math.floor(s / 3600), minutes = Math.floor((s % 3600) / 60), seconds = Math.floor((s % 3600) % 60), ms = `0${minutes}`.slice(-2) + ':' + `0${seconds}`.slice(-2);
    return hours === 0 ? ms : `0${hours}`.slice(-2) + ':' + ms;
}

/**
 * Get an item from a given object using string dot notation.
 */
function dot(obj, ref, def = void 0) {
    const path = type.isArray(ref) ? ref : ref.split('.');
    return path.reduce((o, i) => (type.isUndefined(o) || !o.hasOwnProperty(i) ? def : o[i]), obj);
}

/**
 * Generate a random string of a given length.
 */
function random(length = 16) {
    let str = '';
    while (str.length < length && length > 0) {
        let r = Math.random();
        str +=
            r < 0.1 ? Math.floor(r * 100) : String.fromCharCode(Math.floor(r * 26) + (r > 0.5 ? 97 : 65));
    }
    return str;
}

export { type, value, round, ordinal, time, dot, random };
//# sourceMappingURL=chitu.es.js.map
